@@ -50,9 +50,6 @@ class Variable:
     def addReference(self, reference):
         self.references.append( reference )
 
-    def getReferences(self):
-        return self.references
-
     def getReferenced(self):
         # Abstract method, pylint: disable=R0201,W0613
         return None
@@ -133,14 +130,6 @@ class Variable:
                   not owner.isGenerator() and not owner.needsCreation():
                 owner = owner.getParentVariableProvider()
 
-            # List contractions in Python2 do not really own their variables.
-            # TODO: They ought to not be variable providers/takers at all.
-            # TODO: This code seems unnecessary now due to "needsCreation" not
-            # being true.
-            if Utils.python_version < 300:
-                while owner != top_owner and owner.code_prefix == "listcontr":
-                    owner = owner.getParentVariableProvider()
-
             # This defines being shared. Owned by one, and references that are
             # owned by another node.
             if owner != top_owner:
@@ -149,13 +138,23 @@ class Variable:
             return False
 
 
-    def isShared(self, technical = False):
+    def isSharedLogically(self):
         variable = self
 
         while variable.isClosureReference():
             variable = variable.getReferenced()
 
-        return self._checkShared( variable, technical )
+        return self._checkShared(variable, False)
+
+
+    def isSharedTechnically(self):
+        variable = self
+
+        while variable.isClosureReference():
+            variable = variable.getReferenced()
+
+        return self._checkShared(variable, True)
+
 
     reference_class = None
 
@@ -275,7 +274,7 @@ class ClosureVariableReference(VariableReferenceBase):
                 assert False, self
 
     def getDeclarationTypeCode(self, in_context):
-        if self.getReferenced().isShared( True ):
+        if self.getReferenced().isSharedTechnically():
             if in_context:
                 return "PyObjectClosureVariable"
             else:
@@ -363,7 +362,7 @@ class LocalVariable(Variable):
         return "var_" + Utils.encodeNonAscii( self.getName() )
 
     def getDeclarationTypeCode(self, in_context):
-        if self.isShared( True ):
+        if self.isSharedTechnically():
             return "PyObjectSharedLocalVariable"
         else:
             return "PyObjectLocalVariable"
@@ -445,7 +444,7 @@ class ParameterVariable(LocalVariable):
         return "par_" + Utils.encodeNonAscii( self.getName() )
 
     def getDeclarationTypeCode(self, in_context):
-        if self.isShared( True ):
+        if self.isSharedTechnically():
             return "PyObjectSharedLocalVariable"
         elif self.getHasDelIndicator():
             return "PyObjectLocalParameterVariableWithDel"
@@ -509,9 +508,6 @@ class ModuleVariable(Variable):
     def getModuleName(self):
         return self.module.getFullName()
 
-    def _checkShared(self, variable, technical):
-        assert False, variable
-
 
 class TempVariableClosureReference(VariableReferenceBase):
     reference_class = None
@@ -587,7 +583,7 @@ class TempVariable(Variable):
         return True
 
     def getDeclarationTypeCode(self, in_context):
-        if self.isShared( True ):
+        if self.isSharedTechnically():
             return "PyObjectSharedTempVariable"
         else:
             return "PyObjectTempVariable"
