@@ -23,13 +23,13 @@ answer quite a few questions at compile time.
 
 """
 
-from .NodeBases import (
-    ExpressionBuiltinSingleArgBase,
-    ExpressionBuiltinNoArgBase
-)
-
 from nuitka.optimizations import BuiltinOptimization
 
+from .NodeBases import (
+    ExpressionBuiltinNoArgBase,
+    ExpressionBuiltinSingleArgBase
+)
+
 
 class ExpressionBuiltinOrd0(ExpressionBuiltinNoArgBase):
     kind = "EXPRESSION_BUILTIN_ORD0"
